@@ -1,11 +1,13 @@
 from typing import List
 
+from typing_extensions import Self
+
 
 class _TMIOTabs:
     """
     .. versionadded:: 0.3.0
 
-    _TMIO Endpoints
+    TMIO Endpoints
     """
 
     def __init__(self):
@@ -32,7 +34,7 @@ class _TMIO:
     """
     .. versionadded:: 0.3.0
 
-    Basic _TMIO Api Details
+    Basic TMIO Api Details
 
     Parameters
     ----------
@@ -52,8 +54,8 @@ class _TMIO:
 
     TABS: _TMIOTabs = _TMIOTabs()
 
-    @staticmethod
-    def build(endpoints: List[str]) -> str:
+    @classmethod
+    def build(cls: Self, endpoints: List[str]) -> str:
         """Builds a _TMIO endpoint url.
 
         Parameters
@@ -67,7 +69,7 @@ class _TMIO:
             The built endpoint url.
 
         """
-        url = f"{_TMIO.PROTOCOL}://{_TMIO.BASE}/{_TMIO.API}/"
+        url = f"{cls.PROTOCOL}://{cls.BASE}/{cls.API}/"
 
         if len(endpoints) == 0:
             return url
@@ -86,7 +88,7 @@ class _TMXTabs:
     """
     .. versionadded :: 0.3.3
 
-    _TMX Endpoints
+    TMX Endpoints
     """
 
     def __init__(self):
@@ -101,7 +103,7 @@ class _TMX:
     """
     .. versionadded:: 0.3.0
 
-    Basic _TMX Api Details
+    Basic TMX Api Details
 
     Parameters
     ----------
@@ -121,8 +123,51 @@ class _TMX:
     API: str = "api"
     TABS: _TMXTabs = _TMXTabs()
 
-    @staticmethod
-    def build(endpoints: List[str]) -> str:
+    MAP_TYPE_ENUMS: dict = {
+        1: "Race",
+        2: "FullSpeed",
+        3: "Tech",
+        4: "RPG",
+        5: "LOL",
+        6: "Press Forward",
+        7: "SpeedTech",
+        8: "MultiLap",
+        9: "Offroad",
+        10: "Trial",
+        11: "ZrT",
+        12: "SpeedFun",
+        13: "Competitive",
+        14: "Ice",
+        15: "Dirt",
+        16: "Stunt",
+        17: "Reactor",
+        18: "Platform",
+        19: "Slow Motion",
+        20: "Bumper",
+        21: "Fragile",
+        22: "Scenery",
+        23: "Kacky",
+        24: "Endurance",
+        25: "Mini",
+        26: "Remake",
+        27: "Mixed",
+        28: "Nascar",
+        29: "SpeedDrift",
+        30: "Minigame",
+        31: "Obstacle",
+        32: "Transitional",
+        33: "Grass",
+        34: "Backwards",
+        35: "Freewheel",
+        36: "Signature",
+        37: "Royal",
+        38: "Water",
+        39: "Plastic",
+        40: "Arena",
+    }
+
+    @classmethod
+    def build(cls: Self, endpoints: List[str]) -> str:
         """URL Builder for _TMX API
 
         Parameters
@@ -135,7 +180,7 @@ class _TMX:
         str
             The URL.
         """
-        url = f"{_TMX.PROTOCOL}://{_TMX.BASE}/{_TMX.API}/"
+        url = f"{cls.PROTOCOL}://{cls.BASE}/{cls.API}/"
 
         if len(endpoints) == 0:
             return url
